@@ -287,7 +287,7 @@ class Payment(BaseModel):
     id: UUID
     user_id: UUID
     tenant_id: UUID
-    config_id: UUID
+    service_id: UUID
     created_at: str
     updated_at: str
     status: PaymentStatus
