@@ -153,7 +153,7 @@ def get_payment_event_data(**kwargs):
         'id': 'bb7044e4-066c-4bf7-915e-87ee97270eae',
         'user_id': 'f3323b10-db62-4aeb-95de-a87c1f678dad',
         'tenant_id': '60e35f02-1509-408c-b101-3b1a28109329',
-        'config_id': '68dada78-2398-4a11-b80a-98aaede3371c',
+        'service_id': '68dada78-2398-4a11-b80a-98aaede3371c',
         'created_at': '2024-02-19T15:50:23+01:00',
         'updated_at': '2024-02-20T15:05:16+01:00',
         'status': 'PAYMENT_PENDING',
